@@ -337,6 +337,7 @@ namespace Banshee
 			SetTip(gxml["ToggleButtonRepeat"], Catalog.GetString("Toggle Repeat Playback Mode"));
 			SetTip(gxml["ButtonTrackProperties"], Catalog.GetString("View Selected Song Information"));
 			SetTip(gxml["ButtonBurn"], Catalog.GetString("Burn Selection to CD"));
+			SetTip(gxml["ButtonRip"], Catalog.GetString("Rip CD into Library"));
 			SetTip(gxml["ButtonPrevious"], Catalog.GetString("Play Previous Song"));
 			SetTip(gxml["ButtonPlayPause"], Catalog.GetString("Play/Pause Current Song"));
 			SetTip(gxml["ButtonNext"], Catalog.GetString("Play Next Song"));
@@ -579,7 +580,7 @@ namespace Banshee
             ScaleTime.Adjustment.Upper = ti.Duration;
 
             UpdateMetaDisplay(ti);
-
+            
             TogglePlaying();
 
             ti.IncrementPlayCount();
@@ -953,6 +954,7 @@ namespace Banshee
 				Core.ThreadLeave();
 			}
 			
+			gxml["ButtonRip"].Visible = source.Type == SourceType.AudioCd;
 			gxml["IpodContainer"].Visible = source.Type == SourceType.Ipod;
 		}
 		
